package internal

import (
	"bytes"

	"golang.org/x/term"
)

var (
	CGreen   string
	CRed     string
	CMagenta string
	CReset   string
)

func init() {
	var b bytes.Buffer
	t := term.NewTerminal(&b, "")
	CGreen = string(t.Escape.Green)
	CRed = string(t.Escape.Red)
	CMagenta = string(t.Escape.Magenta)
	CReset = string(t.Escape.Reset)
}
